% FORMULA DEI TRAPEZI PER IL CALCOLO APPROSSIMATO DI INTEGRALI
%
% function I = trapezi(funz,a,b)
%
% DATI DI INPUT:
%  funz = stringa contenente il nome della funzione integranda
%         (definita in un omonimo file .m)
%     a = estremo inferiore dell'intervallo di integrazione
%     b = estremo superiore dell'intervallo di integrazione
%
% DATI DI OUTPUT:
%     I = approssimazione dell'integrale
%

function I = trapezi(funz,a,b)
h = (b-a);
fa = feval(funz,a);
fb = feval(funz,b);
I = (fa + fb) * h/2;
